%==== PACKAGES AND OTHER DOCUMENT CONFIGURATIONS  ====%
\documentclass{resume} % Use the custom resume.cls style
\usepackage[left=0.25in,top=0.25in,right=0.25in,bottom=0.25in]{geometry} % Document margins
\usepackage[T1]{fontenc}
\usepackage{xcolor}
\usepackage{lmodern}
\usepackage[T1]{fontenc}
\usepackage{fontawesome} % For GitHub and LinkedIn symbols
\usepackage{textcomp} % For mobile phone and email symbols
% \usepackage[colorlinks=true, linkcolor=blue, citecolor=blue, urlcolor=blue]{hyperref}
\usepackage{xcolor}  % Required for defining custom colors
\usepackage{hyperref}
% Define your custom colors
% \definecolor{myblue}{RGB}{173, 216, 246}
% \definecolor{myblue}{RGB}{123, 176, 206}
\definecolor{myblue}{RGB}{93, 142, 172}

% Set hyperlink colors
\hypersetup{
    colorlinks=true,
    linkcolor=myblue,
    citecolor=myblue,
    urlcolor=myblue
}

\usepackage{hyperref}

%==== Headings ====%
\name{\VAR{name}} % Your name
\address{
\BLOCK{ if personal.phone }{\faPhone} \href{tel:\VAR{personal.phone}}{\VAR{personal.phone.replace(' ','')}} \quad \BLOCK{ endif }
\BLOCK{ if personal.email }{\faEnvelope} \href{mailto:\VAR{personal.email}}{\VAR{personal.email}} \quad \BLOCK{ endif }
\BLOCK{ if personal.github }{\faGithub} \href{\VAR{personal.github}}{\VAR{personal.github}} \quad \BLOCK{ endif }
\BLOCK{ if personal.linkedin }{\faLinkedin} \href{\VAR{personal.linkedin}}{\VAR{personal.linkedin}} \BLOCK{ endif }
}

\begin{document}

%==== EDUCATION SECTION ====%
\begin{rSection}{Education}
    \BLOCK{ for school in education }
        \BLOCK{ if school.university }
            \textbf{\VAR{school.university}} \hfill {\VAR{school.from} - \VAR{school.to}} \\
            \BLOCK{ if school.degree }
                {\VAR{school.degree}}
            \BLOCK{ endif }
            {(GPA: \VAR{school.grade})} \smallskip \\ 
            \textbf{\textit{Relevant Courses:}}
            \textit{\VAR{', '.join(school.coursework)}}
            \vspace{2mm}
        \BLOCK{ endif } 
    \BLOCK{ endfor }
\end{rSection}

%==== TECHNICAL STRENGTHS SECTION ====%
\BLOCK{ if technical }
    \begin{rSection}{Technical Skills}
        \begin{tabular}{ @{} l @{\hspace{1ex}} l }
            \BLOCK{ for section in technical }
                \textbf{\VAR{section.name}}: \VAR{', '.join(section.skills)}\\
            \BLOCK{ endfor }
            \BLOCK{ if certifications }\textbf{Certifications:} 
                \BLOCK{ for certification in certifications }
                    \href{\VAR{certification.link}}{\textbf{\VAR{certification.name}}},
                \BLOCK{ endfor }
            \BLOCK{ endif } 
        \end{tabular}
    \end{rSection}
\BLOCK{ endif } 

% WORK EXPERIENCE SECTION
\BLOCK{ if work }
    \begin{rSection}{Work Experience}
        \BLOCK{ for exp in work }
            \begin{rSubsection}
                \BLOCK{ if exp.link}
                    {\href{\VAR{exp.link}}{\VAR{exp.company}}}
                \BLOCK{else}
                    {\VAR{exp.company}}
                \BLOCK{ endif }
                {\VAR{exp.location}}
                {\normalfont{\VAR{exp.role}}}{\normalfont{\VAR{exp.from} - \VAR{exp.to}}}
                \BLOCK{ for point in exp.description }
                    \item \VAR{point}
                \BLOCK{ endfor }
            \end{rSubsection}
        \BLOCK{ endfor }
    \end{rSection}
\BLOCK{ endif }

% PROJECTS SECTION
\BLOCK{ if projects }
    \begin{rSection}{Projects}
        \BLOCK{ for project in projects}
            \begin{rSubsection}
                \BLOCK{ if project.link}
                    {\href{\VAR{project.link}}{\VAR{project.name}}}
                \BLOCK{else}
                    {\VAR{project.name}}
                \BLOCK{ endif }
                {\normalfont{\VAR{project.from} - \VAR{project.to}}}{}{}
                \BLOCK{ for point in project.description}
                    \item \VAR{point}
                \BLOCK{ endfor }
            \end{rSubsection}
        \BLOCK{ endfor }
    \end{rSection}
\BLOCK{ endif }

\newcommand\myfontsize{\fontsize{0.1pt}{0.1pt}\selectfont} \myfontsize \color{white}
{Data warehouse, data modeling, data extraction, data transformation, data loading, SQL, ETL, data quality, data governance, data privacy, data visualization, data controls, privacy, security, compliance, SLA, AWS, terabyte to petabyte scale data.}

\end{document}